# Module Index

- spamfighter - СпамоБорец.
  - spamfighter.api - Набор команд, составляющих API СпамоБорца (`sf.*`).
    - spamfighter.api.domain - Набор команд СпамоБорца `sf.domain.*`.
      - spamfighter.api.domain.children - Команда `sf.domain.children` - получение списка имён поддоменов.
      - spamfighter.api.domain.get - Команда `sf.domain.get` - получение информации об одном свойстве домена.
      - spamfighter.api.domain.list - Команда `sf.domain.list` - получение списка имён свойств домена.
      - spamfighter.api.domain.test - Тесты на `spamfighter.api.domain`.
        - spamfighter.api.domain.test.test_children - Тесты на `spamfighter.api.domain.children`.
        - spamfighter.api.domain.test.test_get - Тесты на `spamfighter.api.domain.get`.
        - spamfighter.api.domain.test.test_list - Тесты на `spamfighter.api.domain.list`.
    - spamfighter.api.info - Набор команд СпамоБорца `sf.info.*`.
      - spamfighter.api.info.test - Тесты на `spamfighter.api.info`.
        - spamfighter.api.info.test.test_version - Тесты на `spamfighter.api.info.version`.
      - spamfighter.api.info.version - Команда `sf.info.version` - получение версии сервера
    - spamfighter.api.message - Набор команд СпамоБорца `sf.message.*`.
      - spamfighter.api.message.firewall - Команды `sf.message.firewall.*`.
      - spamfighter.api.message.input - Команда `sf.message.input` - анализ входящего сообщения.
      - spamfighter.api.message.log - Команды `sf.message.log.*`.
      - spamfighter.api.message.test - Тесты на `spamfighter.api.message`.
        - spamfighter.api.message.test.test_firewall - Тесты на `spamfighter.api.message.firewall`.
        - spamfighter.api.message.test.test_input - Тесты на `spamfighter.api.message.input`.
        - spamfighter.api.message.test.test_log - Тесты на `spamfighter.api.message.log`.
    - spamfighter.api.model - Набор команд СпамоБорца `sf.model.*`.
      - spamfighter.api.model.classify - Команда `sf.model.classify` - классификация по модели.
      - spamfighter.api.model.test - Тесты на `spamfighter.api.model`.
        - spamfighter.api.model.test.test_classify - Тесты на `spamfighter.api.model.classify`.
        - spamfighter.api.model.test.test_train - Тесты на `spamfighter.api.model.train`.
      - spamfighter.api.model.train - Команда `sf.model.train` - обучение модели.
  - spamfighter.core - Ядро сервера: базовые классы команд, доменов, партнеров и т.п.
    - spamfighter.core.commands - Базовые классы для обработки команд API сервера.
      - spamfighter.core.commands.apiglue - "Клей", позволяющий приклеить нашу систему команд к Twisted-варианту XML-RPC & JSON-RPC.
      - spamfighter.core.commands.command - Базовый класс команды API.
      - spamfighter.core.commands.dispatcher - Диспетчеризация команд по имени.
      - spamfighter.core.commands.errors - Базовые классы обработки ошибок при выполнении команд.
      - spamfighter.core.commands.partner - Команды с поддержкой выбора партнера и домена.
      - spamfighter.core.commands.serialize - Поддержка сериализации/десериализации для типов данных, передаваемых в командах.
      - spamfighter.core.commands.test - Тесты на `spamfighter.core.commands`.
        - spamfighter.core.commands.test.test_apiglue - Тесты на `spamfighter.core.commands.apiglue`.
        - spamfighter.core.commands.test.test_command - Тесты на `spamfighter.core.commands.command`.
        - spamfighter.core.commands.test.test_dispatcher - Тесты на `spamfighter.core.commands.dispatcher`.
        - spamfighter.core.commands.test.test_partner - Тесты на `spamfighter.core.commands.partner`.
        - spamfighter.core.commands.test.test_serialize - Тесты на `spamfighter.core.commands.serialize`.
    - spamfighter.core.counters - Счетчики, анализирующие нагрузку на сервер.
    - spamfighter.core.domain - Реализация основных классов доменов.
    - spamfighter.core.firewall - "Черный ящик" анализа сообщений по правилам, построенный
    - spamfighter.core.log - Лог сообщений, прошедших через firewall.
    - spamfighter.core.message - Сообщения, атрибуты, их домены и т.п.
      - spamfighter.core.message.attribute - Атрибуты сообщений и их домены.
      - spamfighter.core.message.message - Сообщения, домены сообщений.
      - spamfighter.core.message.serialize - Сериализация сообщений, взаимодействие с командами.
      - spamfighter.core.message.test - Тесты на `spamfighter.core.message`.
        - spamfighter.core.message.test.test_attribute - Тесты на `spamfighter.core.message.attribute`.
        - spamfighter.core.message.test.test_message - Тесты на `spamfighter.core.message.message`.
        - spamfighter.core.message.test.test_serialize - Тесты на `spamfighter.core.message.serialize`.
    - spamfighter.core.model - Модели анализа сообщений.
      - spamfighter.core.model.bayes - Модель анализа сообщений по Байесу.
      - spamfighter.core.model.command - Базовый класс команд работы с моделью.
      - spamfighter.core.model.test - Тесты на `spamfighter.core.model`.
        - spamfighter.core.model.test.test_bayes - Тесты на `spamfighter.core.model.bayes`.
        - spamfighter.core.model.test.test_command - Тесты на `spamfighter.core.model.command`.
      - spamfighter.core.model.thomas - No module docstring; 1/3 classes, 1/1 functions documented
    - spamfighter.core.null_partner - Модуль авторизации партнеров без логинов/паролей (на доверии).
    - spamfighter.core.partner - Базовые классы и методы работы с партнерами.
    - spamfighter.core.rules - Обслуживание правил для анализа сообщений.
    - spamfighter.core.storage - Модули подсистемы хранения данных, как персистентного, так и временного.
      - spamfighter.core.storage.dbm - Подсистема хранения данных на локальном диске в BDB-подобной БД.
      - spamfighter.core.storage.memory - Подсистема временного хранения данных в памяти.
      - spamfighter.core.storage.test - Тесты на `spamfighter.core.storage`.
        - spamfighter.core.storage.test.base - Базовые варианты тестовых сценариев на хранилища.
        - spamfighter.core.storage.test.test_dbm - Тесты на `spamfighter.core.storage.dbm`.
        - spamfighter.core.storage.test.test_memory - Тесты на `spamfighter.core.storage.memory`.
    - spamfighter.core.test - Тесты на `spamfighter.core`.
      - spamfighter.core.test.test_counters - Тесты на `spamfighter.core.counters`.
      - spamfighter.core.test.test_domain - Тесты на `spamfighter.core.domain`.
      - spamfighter.core.test.test_firewall - Тесты на `spamfighter.core.firewall`.
      - spamfighter.core.test.test_log - Тесты на `spamfighter.core.log`.
      - spamfighter.core.test.test_null_partner - Тест на `spamfighter.core.null_partner`.
      - spamfighter.core.test.test_partner - Тесты на `spamfighter.core.partner`.
      - spamfighter.core.test.test_rules - Тесты на `spamfighter.core.rules`.
  - spamfighter.interfaces - Базовые интерфейсы проекта.
  - spamfighter.plugin - Подсистема плагинов СпамоБорца и интерфейсы плагинов.
  - spamfighter.plugins - Базовый каталог плагинов.
    - spamfighter.plugins.null_partner_authorizer_provider - Плагин, реализующий авторизацию партнеров без логинов/паролей (доверительный вариант).
    - spamfighter.plugins.sample_domain_provider - Плагин, реализующий корневой домен в качестве возможного примера организации.
    - spamfighter.plugins.static_domain_provider - Плагин, реализующий статический домен по умолчанию.
    - spamfighter.plugins.test - Тесты на плагины.
      - spamfighter.plugins.test.test_null_partner_authorizer_provider - Тесты на `spamfighter.plugins.null_partner_authorizer_provider`.
      - spamfighter.plugins.test.test_static_doman_provider - Тесты на `spamfighter.plugins.static_domain_provider`.
  - spamfighter.rules - Набор правил анализа сообщений СпамоБорца.
    - spamfighter.rules.analyze - Набор правил аналица текста сообщений
    - spamfighter.rules.frequency - Набор правил проверки текста сообщений на частоту
    - spamfighter.rules.log - Правила, управляющие логом сообщений.
    - spamfighter.rules.model - Правила, управляющие моделями.
    - spamfighter.rules.test - Тесты на `spamfighter.rules`.
      - spamfighter.rules.test.test_analyze - Тесты на `spamfighter.rules.analyze`.
      - spamfighter.rules.test.test_frequency - Тесты на `spamfighter.rules.frequency`.
      - spamfighter.rules.test.test_log - Тесты на `spamfighter.rules.log`.
      - spamfighter.rules.test.test_model - Тесты на `spamfighter.rules.model`.
      - spamfighter.rules.test.test_validate - Тесты на `spamfighter.rules.validate`.
    - spamfighter.rules.validate - Модуль содержащий правила проверки сообщений
  - spamfighter.scripts - Различные сервисные скрипты.
    - spamfighter.scripts.create - Скрипт создания каталога для инсталляции СпамоБорца.
  - spamfighter.service - Построение сервисов, составляющих ядро сервера.
  - spamfighter.test - Тесты на `spamfighter`.
    - spamfighter.test.plugins - Плагины для тестов.
      - spamfighter.test.plugins.plugin_test_1 - Undocumented
      - spamfighter.test.plugins.plugin_test_2 - Undocumented
    - spamfighter.test.test_plugin - Тесты на `spamfighter.plugin`.
  - spamfighter.txjsonrpc - No package docstring; 1/1 modules, 0/3 packages documented
    - spamfighter.txjsonrpc.jsonrpclib - Requires simplejson; can be downloaded from
    - spamfighter.txjsonrpc.netstring - No package docstring; 1/1 modules, 0/1 packages documented
      - spamfighter.txjsonrpc.netstring.jsonrpc - A generic resource for publishing objects via JSON-RPC.
      - spamfighter.txjsonrpc.netstring.test - No package docstring; 1/1 modules documented
        - spamfighter.txjsonrpc.netstring.test.test_jsonrpc - Test JSON-RPC over TCP support.
    - spamfighter.txjsonrpc.test - Undocumented
      - spamfighter.txjsonrpc.test.test_jsonrpclib - Undocumented
    - spamfighter.txjsonrpc.web - No package docstring; 1/1 modules, 0/1 packages documented
      - spamfighter.txjsonrpc.web.jsonrpc - A generic resource for publishing objects via JSON-RPC.
      - spamfighter.txjsonrpc.web.test - No package docstring; 1/1 modules documented
        - spamfighter.txjsonrpc.web.test.test_jsonrpc - Test JSON-RPC support.
  - spamfighter.utils - Различные утилиты и вспомогательные классы.
    - spamfighter.utils.config - Питоновский враппер конфигурационных XML файлов
    - spamfighter.utils.registrator - Декоратор регистрации, позволяющий получить текущий класс в функции,
    - spamfighter.utils.terminal - Terminal controller module.
    - spamfighter.utils.test - Тесты на `spamfighter.utils`.
      - spamfighter.utils.test.test_config - Тесты на `spamfighter.utils.config`.
      - spamfighter.utils.test.test_registrator - Тесты на `spamfighter.utils.registrator`.
      - spamfighter.utils.test.test_time - Тесты на `spamfighter.utils.time`.
    - spamfighter.utils.time - Модуль подсчета "неточного" времени (разрешение одна секунда). Доступен